# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add qa_pass action for 'Await QA' to 'Complete' transition

Revision ID: 22db21f0ecb2
Revises: 2e185d05a21f
Create Date: 2021-10-27 09:26:21.350993

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "22db21f0ecb2"
down_revision = "2e185d05a21f"
branch_labels = None
depends_on = None


def upgrade():
    """
    add action for Awaiting QA => Complete transition

    :return:
    """
    op.execute(
        """
INSERT INTO capability_state_actions
    (transition_id, arguments, action_type)
    VALUES (
            (SELECT transition_id FROM capability_state_transitions
                WHERE capability_name='std_calibration'
                AND from_state='Awaiting QA'
                AND to_state='Complete'),
           'qa_pass', 'ExecuteWorkflow'
        )
    """
    )


def downgrade():
    """
    remove action for Awaiting QA => Complete transition

    :return:
    """
    op.execute(
        """
DELETE FROM capability_state_actions
WHERE action_type='ExecuteWorkflow'
AND arguments='qa_pass'
AND transition_id=(
    SELECT transition_id FROM capability_state_transitions
    WHERE capability_name='std_calibration'
      AND from_state='Awaiting QA'
      AND to_state='Complete'
      AND action_type='qa_pass'
    )
    """
    )
